@@ -403,7 +403,7 @@ sub parse_date {
     }
     my $tz;
     if ($time[6]) {
-        $tz = Bugzilla->local_timezone->offset_as_string($time[6]);
+        $tz = DateTime::TimeZone->offset_as_string($time[6]);
     }
     else {
         $tz = $self->config('timezone');
